@@ -112,8 +112,8 @@ class ApiSettings(ApiBase):
     def terraform_versions(self):
         return self.build_route("settings/tfversion")
 
-    def custom_tags(self):
+    def tags(self):
         return self.build_route("settings/tags")
 
-    def custom_tag(self, name: str):
+    def tag(self, name: str):
         return self.build_route(f"settings/tags/{name}")
