@@ -35,6 +35,15 @@ class ColonyAccount:
         self.first_name = first_name
         self.last_name = last_name
 
+    @property
+    def display_first_name(self):
+        return self.first_name or self.email
+
+    @property
+    def display_last_name(self):
+        return self.last_name
+
+
 
 class BlueprintRepositoryDetails:
     def __init__(self, repository_url: str, access_token: str, repository_type: str, branch: str = None):
@@ -217,10 +226,12 @@ class SpaceHelmChartOutput:
 class HelmChartDescriptor:
     def __init__(self, name: str, perform_helm_test: bool, enable_logs: bool, inputs: List[SpaceHelmChartInput],
                  outputs: List[SpaceHelmChartOutput], compute_service: SpaceHelmChartComputeService,
-                 chart_root_path: Optional[str] = None, description: Optional[str] = None,
-                 override_values_yaml: Optional[str] = None, commands: Optional[List[str]] = None):
+                 chart_root_path: Optional[str] = None, git_branch: Optional[str] = None,
+                 description: Optional[str] = None, override_values_yaml: Optional[str] = None,
+                 commands: Optional[List[str]] = None):
         self.name = name
         self.chart_root_path = chart_root_path
+        self.git_branch = git_branch
         self.description = description
         self.enable_logs = enable_logs
         self.perform_helm_test = perform_helm_test
