@@ -46,13 +46,14 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 BlueprintValidationResponse, ArtifactRepoCreatedUser,
                                                 ArtifactRepoResponse, CatalogForGetAllResponse, CatalogForGetResponse,
                                                 SpaceCloudAccount, SpaceAdmin, SandboxOutput, ServiceTfProgressResponse,
-                                                TerraformModuleDescriptorResponse, CustomTagResponse,
-                                                CustomTagOverrideResponse, ServiceTfLogsResponse,
+                                                TerraformModuleDescriptorResponse, TagResponse,
+                                                TagOverrideResponse, ServiceTfLogsResponse,
                                                 ServiceTfLogInfo, SpaceTerraformModuleResponse, BlueprintTagResponse,
                                                 AccountRepositoryItemResponse, SpaceHelmChartResponse,
                                                 TerraformServiceResponse, HelmServiceResponse,
-                                                CustomTagWithStatisticsResponse, BlueprintPolicyResponse,
-                                                HelmServiceLogResponse)
+                                                TagWithStatisticsResponse, BlueprintPolicyResponse,
+                                                ComputeServiceProperties, HelmServiceLogResponse,
+                                                StageResponse, ActivityResponse, TimeDataResponse, TagType)
 
 
 class Converters:
@@ -66,6 +67,9 @@ class Converters:
             SpaceAdmin(
                 first_name=admin["first_name"],
                 last_name=admin["last_name"],
+                display_first_name=admin["display_first_name"],
+                display_last_name=admin["display_last_name"],
+                email=admin["email"],
                 account_role=admin["account_role"],
             )
             for admin in space["admins"]
@@ -162,6 +166,8 @@ class Converters:
                 created_by_json["email"],
                 created_by_json["first_name"],
                 created_by_json["last_name"],
+                created_by_json["display_first_name"],
+                created_by_json["display_last_name"],
             ),
         )
 
@@ -269,6 +275,8 @@ class Converters:
                 created_by=compute_service.get("created_by", None),
                 user_defined=compute_service.get("user_defined", None),
                 status=compute_service.get("status", None),
+                properties=ComputeServiceProperties(compute_service.get("properties", None)['agent_namespace'],
+                                                    compute_service.get("properties", None)['sandboxes_namespaces']),
                 spaces=compute_service.get("spaces", [])
             )
             for compute_service in cloud_compute_services
@@ -429,7 +437,7 @@ class Converters:
             source=Converters._create_source(sandbox.get('source')),
             direct_access=sandbox.get('direct_access', 'off'),
             outputs=Converters._create_sandbox_outputs(sandbox.get('outputs')),
-            tags=Converters.create_custom_tag_response_list(sandbox.get('tags'))
+            tags=Converters.create_tag_response_list(sandbox.get('tags'))
         )
 
     @staticmethod
@@ -478,7 +486,7 @@ class Converters:
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
             direct_access=production.get('direct_access', 'off'),
             outputs=Converters._create_sandbox_outputs(production['outputs']),
-            tags=Converters.create_custom_tag_response_list(production.get('tags'))
+            tags=Converters.create_tag_response_list(production.get('tags'))
         )
 
     @staticmethod
@@ -516,7 +524,7 @@ class Converters:
             launching_progress=Converters._create_launching_progress(production.get('launching_progress')),
             direct_access=production.get('direct_access', 'off'),
             outputs=Converters._create_sandbox_outputs(production['outputs']),
-            tags=Converters.create_custom_tag_response_list(production.get('tags'))
+            tags=Converters.create_tag_response_list(production.get('tags'))
         )
 
     @staticmethod
@@ -527,6 +535,8 @@ class Converters:
         return SandboxOwnerResponse(
             first_name=user["first_name"],
             last_name=user["last_name"],
+            display_first_name=user["display_first_name"],
+            display_last_name=user["display_last_name"],
             email=user["email"],
             join_date=user["join_date"],
         )
@@ -778,6 +788,8 @@ class Converters:
         return UserPermittedToSpaceResponse(
             first_name=user["first_name"],
             last_name=user["last_name"],
+            display_first_name=user["display_first_name"],
+            display_last_name=user["display_last_name"],
             email=user["email"],
             join_date=user["join_date"],
             space_role=user["space_role"],
@@ -798,6 +810,8 @@ class Converters:
             email=user["email"],
             first_name=user["first_name"],
             last_name=user["last_name"],
+            display_first_name=user["display_first_name"],
+            display_last_name=user["display_last_name"],
             join_date=user["join_date"],
             account_role=user["account_role"],
             has_access_to_all_spaces=user["has_access_to_all_spaces"],
@@ -1008,6 +1022,7 @@ class Converters:
                 status=service["status"],
                 service_type=service["type"],
                 progress=Converters._create_tf_progress_response(service["progress"]),
+                stages=Converters._create_stages_response(service["stages"]),
                 logs=Converters._create_tf_logs_response(service["logs"])
             )
         elif service["type"] == ServiceType.Helm:
@@ -1016,11 +1031,50 @@ class Converters:
                 status=service["status"],
                 service_type=service["type"],
                 progress=service["progress"],
+                stages=Converters._create_stages_response(service["stages"]),
                 logs=Converters._create_helm_logs_response(service["logs"])
             )
         else:
             raise Exception("Unsupported service type")
 
+    @staticmethod
+    def _create_stages_response(stages_dict: dict) -> List[StageResponse]:
+        if stages_dict is None:
+            return []
+
+        stage_responses = []
+
+        for stage in stages_dict:
+            stage_responses.append(StageResponse(
+                name=stage["name"],
+                stage_id=stage["id"],
+                status=stage["status"],
+                time=Converters._create_time_data_response(stage["time"]),
+                activities=Converters._create_activities_response(stage["activities"])))
+
+        return stage_responses
+
+    @staticmethod
+    def _create_activities_response(activities_dict: dict) -> List[ActivityResponse]:
+        activities_responses = []
+
+        for activity in activities_dict:
+            activities_responses.append(ActivityResponse(
+                name=activity["name"],
+                status=activity["status"],
+                time=Converters._create_time_data_response(activity["time"]),
+                log=activity["log"]))
+
+        return activities_responses
+
+    @staticmethod
+    def _create_time_data_response(time_data_dict: dict) -> TimeDataResponse:
+        if time_data_dict is None:
+            return None
+
+        return TimeDataResponse(time_data_dict["start"],
+                                time_data_dict["duration"])
+
     @staticmethod
     def _create_helm_logs_response(logs_dict: dict) -> Optional[Dict[str, HelmServiceLogResponse]]:
         if logs_dict is None:
@@ -1250,26 +1304,14 @@ class Converters:
             account_name=data['account_name'],
             user_email=data['user_email'],
             first_name=data['first_name'],
-            last_name=data['last_name']
+            last_name=data['last_name'],
+            display_first_name=data["display_first_name"],
+            display_last_name=data["display_last_name"],
         )
 
     @staticmethod
-    def create_custom_tag_response(data: dict) -> CustomTagResponse:
-        return CustomTagResponse(
-            name=data['name'],
-            value=data['value'],
-            scope=data['scope'],
-            possible_values=data['possible_values'],
-            description=data['description'],
-            modified_by=data['modified_by'],
-            last_modified=data['last_modified'],
-            created_by=data['created_by'],
-            created_date=data['created_date']
-        )
-
-    @staticmethod
-    def create_custom_tag_with_statistics_response(data: dict) -> CustomTagWithStatisticsResponse:
-        return CustomTagWithStatisticsResponse(
+    def create_tag_response(data: dict) -> TagResponse:
+        return TagResponse(
             name=data['name'],
             value=data['value'],
             scope=data['scope'],
@@ -1279,7 +1321,22 @@ class Converters:
             last_modified=data['last_modified'],
             created_by=data['created_by'],
             created_date=data['created_date'],
-            tag_type=data['tag_type'],
+            tag_type=TagType(data['tag_type'])
+        )
+
+    @staticmethod
+    def create_tag_with_statistics_response(data: dict) -> TagWithStatisticsResponse:
+        return TagWithStatisticsResponse(
+            name=data['name'],
+            value=data['value'],
+            scope=data['scope'],
+            possible_values=data['possible_values'],
+            description=data['description'],
+            modified_by=data['modified_by'],
+            last_modified=data['last_modified'],
+            created_by=data['created_by'],
+            created_date=data['created_date'],
+            tag_type=TagType(data['tag_type']),
             overridden_values=data['overridden_values'],
             missing_overrides=data['missing_overrides'],
             missing_overrides_space=data['missing_overrides_space'],
@@ -1287,14 +1344,14 @@ class Converters:
             missing_overrides_production_blueprints=data['missing_overrides_production_blueprints'])
 
     @staticmethod
-    def create_custom_tag_response_list(custom_tags: Optional[List[dict]]) -> Optional[List[CustomTagResponse]]:
-        if custom_tags is None:
+    def create_tag_response_list(tags: Optional[List[dict]]) -> Optional[List[TagResponse]]:
+        if tags is None:
             return None
-        return [Converters.create_custom_tag_response(custom_tag) for custom_tag in custom_tags]
+        return [Converters.create_tag_response(tag) for tag in tags]
 
     @staticmethod
-    def create_custom_tag_override_response(data: dict) -> CustomTagOverrideResponse:
-        return CustomTagOverrideResponse(
+    def create_tag_override_response(data: dict) -> TagOverrideResponse:
+        return TagOverrideResponse(
             name=data['name'],
             value=data['value'],
             modified_by=data['modified_by'],
@@ -1419,6 +1476,7 @@ class Converters:
             compute_service=Converters.convert_space_helm_chart_compute_service(
                 data["compute_service"]),
             chart_root_path=data["chart_root_path"],
+            git_branch=data["git_branch"],
             override_values_yaml=data["override_values_yaml"],
             description=data["description"],
             created_by=data["created_by"],
