@@ -51,12 +51,23 @@ class SpaceCloudAccountInfraSettingsRequest:
 
 
 class UserSignupRequest:
-    def __init__(self, first_name: str, last_name: str, password: str, secret: str):
+    def __init__(self, first_name: str, last_name: str, password: str, secret: str, email: str):
         self.first_name = first_name
         self.last_name = last_name
         self.password = password
         self.secret = secret
 
+        # email is not part of the request, but it's needed to calculate display_first_name
+        self.email = email
+
+    @property
+    def display_first_name(self):
+        return self.first_name or self.email
+
+    @property
+    def display_last_name(self):
+        return self.last_name
+
 
 class CreateInvitationsRequest:
     def __init__(
@@ -127,7 +138,7 @@ class NewUserSurveyRequest:
         self.primary_platforms = primary_platforms if primary_platforms is not None else []
 
 
-class CustomTagRequest:
+class TagRequest:
     def __init__(
             self,
             name: str,
@@ -143,7 +154,7 @@ class CustomTagRequest:
         self.description = description
 
 
-class CustomTagOverrideRequest:
+class TagOverrideRequest:
     def __init__(
             self,
             name: str,
@@ -232,12 +243,14 @@ class AddSpaceHelmChartRequest(metaclass=ABCMeta):
             description: Optional[str] = None,
             commands: Optional[List[str]] = None,
             override_values_yaml: Optional[str] = None,
+            git_branch: Optional[str] = None,
     ):
         self.name = name
         self.description = description
         self.compute_service = compute_service
         self.perform_helm_test = perform_helm_test
         self.chart_root_path = chart_root_path
+        self.git_branch = git_branch
         self.enable_logs = enable_logs
         self.override_values_yaml = override_values_yaml
         self.inputs = inputs
@@ -258,12 +271,14 @@ class UpdateSpaceHelmChartRequest(metaclass=ABCMeta):
             description: Optional[str] = None,
             commands: Optional[List[str]] = None,
             override_values_yaml: Optional[str] = None,
+            git_branch: Optional[str] = None,
     ):
         self.name = name
         self.description = description
         self.compute_service = compute_service
         self.perform_helm_test = perform_helm_test
         self.chart_root_path = chart_root_path
+        self.git_branch = git_branch
         self.enable_logs = enable_logs
         self.override_values_yaml = override_values_yaml
         self.inputs = inputs
