@@ -33,6 +33,8 @@ class AccountStatusUserDetails:
     def __init__(self, user_details: {}):
         self.last_name = user_details["last_name"]
         self.first_name = user_details["first_name"]
+        self.display_last_name = user_details["display_last_name"]
+        self.display_first_name = user_details["display_first_name"]
         self.email = user_details["email"]
         self.permitted_spaces = user_details["permitted_spaces"]
         self.account_permissions = user_details["account_permissions"]
@@ -227,9 +229,11 @@ class BlueprintCloudResponse:
 
 
 class ArtifactRepoCreatedUser:
-    def __init__(self, email: str, first_name: str, last_name: str):
+    def __init__(self, email: str, first_name: str, last_name: str, display_first_name: str, display_last_name: str):
         self.last_name = last_name
         self.first_name = first_name
+        self.display_first_name = display_first_name
+        self.display_last_name = display_last_name
         self.email = email
 
 
@@ -421,9 +425,12 @@ class ApplicationResponse(ApplicationResponseBase):
 
 
 class SandboxOwnerResponse:
-    def __init__(self, first_name: str, last_name: str, email: str, join_date: str):
+    def __init__(self, first_name: str, last_name: str, display_first_name: str, display_last_name: str, email: str,
+                 join_date: str):
         self.first_name = first_name
         self.last_name = last_name
+        self.display_first_name = display_first_name
+        self.display_last_name = display_last_name
         self.email = email
         self.join_date = join_date
 
@@ -519,14 +526,50 @@ class ServiceTfProgressResponse:
         self.tf_destroy_status = tf_destroy_status
 
 
+class TimeDataResponse:
+    def __init__(self,
+                 start: str,
+                 duration: str):
+        self.start = start
+        self.duration = duration
+
+
+class ActivityResponse:
+    def __init__(self,
+                 name: str,
+                 status: str,
+                 log: str,
+                 time: TimeDataResponse):
+        self.name = name
+        self.status = status
+        self.log = log
+        self.time = time
+
+
+class StageResponse:
+    def __init__(self,
+                 name: str,
+                 stage_id: str,
+                 status: str,
+                 time: TimeDataResponse,
+                 activities: List[ActivityResponse]):
+        self.name = name
+        self.stage_id = stage_id
+        self.status = status
+        self.time = time
+        self.activities = activities
+
+
 class ServiceResponse:
     def __init__(self,
                  name: str,
                  service_type: str,
-                 status: str):
+                 status: str,
+                 stages: List[StageResponse]):
         self.name = name
         self.type = service_type
         self.status = status
+        self.stages = stages
 
 
 class ServiceTfLogInfo:
@@ -559,8 +602,9 @@ class TerraformServiceResponse(ServiceResponse):
                  service_type: str,
                  status: str,
                  progress: ServiceTfProgressResponse,
+                 stages: List[StageResponse],
                  logs: ServiceTfLogsResponse = None):
-        super().__init__(name=name, service_type=service_type, status=status)
+        super().__init__(name=name, service_type=service_type, status=status, stages=stages)
         self.progress = progress
         self.logs = logs
 
@@ -583,35 +627,20 @@ class HelmServiceResponse(ServiceResponse):
                  service_type: str,
                  status: str,
                  progress: Dict[str,str],
+                 stages: List[StageResponse],
                  logs: Dict[str, HelmServiceLogResponse] = None):
-        super().__init__(name=name, service_type=service_type, status=status)
+        super().__init__(name=name, service_type=service_type, status=status, stages=stages)
         self.progress = progress
         self.logs = logs
 
 
-class CustomTagResponse:
-    def __init__(self,
-                 name: str,
-                 value: str,
-                 scope: str,
-                 possible_values: [],
-                 description: str,
-                 modified_by: str,
-                 last_modified: datetime,
-                 created_by: str,
-                 created_date: datetime):
-        self.name = name
-        self.value = value
-        self.scope = scope
-        self.possible_values = possible_values
-        self.description = description
-        self.modified_by = modified_by
-        self.last_modified = last_modified
-        self.created_date = created_date
-        self.created_by = created_by
+class TagType(Enum):
+    SYSTEM = 'system'
+    PRE_DEFINED = 'pre_defined'
+    USER_DEFINED = 'user_defined'
 
 
-class CustomTagWithStatisticsResponse(CustomTagResponse):
+class TagResponse:
     def __init__(self,
                  name: str,
                  value: str,
@@ -622,7 +651,31 @@ class CustomTagWithStatisticsResponse(CustomTagResponse):
                  last_modified: datetime,
                  created_by: str,
                  created_date: datetime,
-                 tag_type: str,
+                 tag_type: TagType):
+        self.name = name
+        self.value = value
+        self.scope = scope
+        self.possible_values = possible_values
+        self.description = description
+        self.modified_by = modified_by
+        self.last_modified = last_modified
+        self.created_date = created_date
+        self.created_by = created_by
+        self.tag_type = tag_type
+
+
+class TagWithStatisticsResponse(TagResponse):
+    def __init__(self,
+                 name: str,
+                 value: str,
+                 scope: str,
+                 possible_values: [],
+                 description: str,
+                 modified_by: str,
+                 last_modified: datetime,
+                 created_by: str,
+                 created_date: datetime,
+                 tag_type: TagType,
                  overridden_values: int,
                  missing_overrides: int,
                  missing_overrides_space: List[str],
@@ -636,8 +689,8 @@ class CustomTagWithStatisticsResponse(CustomTagResponse):
                          modified_by,
                          last_modified,
                          created_by,
-                         created_date)
-        self.tag_type = tag_type
+                         created_date,
+                         tag_type)
         self.overridden_values = overridden_values
         self.missing_overrides = missing_overrides
         self.missing_overrides_space = missing_overrides_space
@@ -669,7 +722,7 @@ class SandboxResponse(SandboxResponseBase):
                  source: BlueprintSourceResponse,
                  direct_access: str,
                  outputs: Optional[List[SandboxOutput]],
-                 tags: List[CustomTagResponse]):
+                 tags: List[TagResponse]):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -793,7 +846,7 @@ class ProductionResponse(metaclass=abc.ABCMeta):
             launching_progress: LaunchingProgress,
             direct_access: str,
             outputs: Optional[List[SandboxOutput]],
-            tags: List[CustomTagResponse]):
+            tags: List[TagResponse]):
         self.production_id = production_id
         self.sandbox_id = sandbox_id
         self.name = name
@@ -846,7 +899,7 @@ class ProductionBlueResponse(ProductionResponse):
                  launching_progress: LaunchingProgress,
                  direct_access: str,
                  outputs: Optional[List[SandboxOutput]],
-                 tags: List[CustomTagResponse]):
+                 tags: List[TagResponse]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -901,7 +954,7 @@ class ProductionGreenResponse(ProductionResponse):
                  launching_progress: LaunchingProgress,
                  direct_access: str,
                  outputs: Optional[List[SandboxOutput]],
-                 tags: List[CustomTagResponse]):
+                 tags: List[TagResponse]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -935,6 +988,8 @@ class UserPermittedToSpaceResponse:
             self,
             first_name: str,
             last_name: str,
+            display_first_name: str,
+            display_last_name: str,
             email: str,
             join_date: str,
             space_role: str,
@@ -942,6 +997,8 @@ class UserPermittedToSpaceResponse:
             has_access_to_all_spaces: bool):
         self.first_name = first_name
         self.last_name = last_name
+        self.display_first_name = display_first_name
+        self.display_last_name = display_last_name
         self.email = email
         self.join_date = join_date
         self.space_role = space_role
@@ -954,6 +1011,14 @@ class CloudAccountCostResponse:
         self.last_update = last_update
 
 
+class ComputeServiceProperties:
+    def __init__(self,
+                 agent_namespace: str,
+                 sandboxes_namespaces: List[str]):
+        self.agent_namespace = agent_namespace
+        self.sandboxes_namespace = sandboxes_namespaces
+
+
 class ComputeServiceBaseResponse:
     def __init__(self,
                  name: str,
@@ -977,10 +1042,12 @@ class ComputeServiceInAccountResponse(ComputeServiceBaseResponse):
                  created_date: datetime,
                  created_by: str,
                  user_defined: bool,
+                 properties: ComputeServiceProperties,
                  status: str,
                  spaces: List[str]):
         super().__init__(name, service_type, created_date, created_by, user_defined, status)
         self.spaces = spaces
+        self.properties = properties
 
 
 class CloudAccountResponse:
@@ -1171,9 +1238,12 @@ class RepositoryRelationshipResponse:
 
 
 class SpaceAdmin:
-    def __init__(self, first_name: str, last_name: str, account_role: str):
+    def __init__(self, first_name: str, last_name: str, display_first_name: str, display_last_name: str, email: str, account_role: str):
         self.last_name = last_name
         self.first_name = first_name
+        self.display_last_name = display_last_name
+        self.display_first_name = display_first_name
+        self.email = email
         self.account_role = account_role
 
 
@@ -1212,6 +1282,8 @@ class UserForAllUsersResponse:
                  email: str,
                  first_name: str,
                  last_name: str,
+                 display_first_name: str,
+                 display_last_name: str,
                  join_date: str,
                  account_role: str,
                  has_access_to_all_spaces: bool,
@@ -1219,6 +1291,8 @@ class UserForAllUsersResponse:
         self.email = email
         self.first_name = first_name
         self.last_name = last_name
+        self.display_first_name = display_first_name
+        self.display_last_name = display_last_name
         self.join_date = join_date
         self.account_role = account_role
         self.has_access_to_all_spaces = has_access_to_all_spaces
@@ -1371,14 +1445,17 @@ class ParameterStoreItem:
 
 
 class CreateAccountFinalizeResponse:
-    def __init__(self, account_name: str, user_email: str, first_name: str, last_name: str):
+    def __init__(self, account_name: str, user_email: str, first_name: str, last_name: str,
+                 display_first_name: str, display_last_name: str):
         self.account_name = account_name
         self.user_email = user_email
         self.first_name = first_name
         self.last_name = last_name
+        self.display_first_name = display_first_name
+        self.display_last_name = display_last_name
 
 
-class CustomTagOverrideResponse:
+class TagOverrideResponse:
     def __init__(self,
                  name: str,
                  value: str,
@@ -1451,6 +1528,7 @@ class SpaceHelmChartResponse:
             outputs: List[SpaceHelmChartOutput],
             compute_service: SpaceHelmChartComputeService,
             chart_root_path: Optional[str],
+            git_branch: Optional[str],
             description: Optional[str],
             override_values_yaml: Optional[str],
             created_by: str,
@@ -1462,8 +1540,9 @@ class SpaceHelmChartResponse:
         self.chart_descriptor = HelmChartDescriptor(name=name, perform_helm_test=perform_helm_test,
                                                     enable_logs=enable_logs, inputs=inputs,
                                                     outputs=outputs, compute_service=compute_service,
-                                                    chart_root_path=chart_root_path, description=description,
-                                                    override_values_yaml=override_values_yaml, commands=commands)
+                                                    chart_root_path=chart_root_path, git_branch=git_branch,
+                                                    description=description, override_values_yaml=override_values_yaml,
+                                                    commands=commands)
         self.created_by = created_by
         self.created_date = created_date
         self.modified_by = modified_by
