@@ -114,7 +114,7 @@ class DefaultComputeServices:
                                            DefaultComputeServices.AZURE_VM.lower()]
 
 
-class CustomTagScopes:
+class TagScopes:
     ACCOUNT_TAG_SCOPE = 'account'
     SPACE_TAG_SCOPE = 'space'
     BLUEPRINT_TAG_SCOPE = 'blueprint'
